aboutsummaryrefslogtreecommitdiffstats
path: root/Alc
diff options
context:
space:
mode:
Diffstat (limited to 'Alc')
-rw-r--r--Alc/mixer.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/Alc/mixer.c b/Alc/mixer.c
index e7a924bf..cde29c08 100644
--- a/Alc/mixer.c
+++ b/Alc/mixer.c
@@ -209,8 +209,8 @@ static inline double CalcKaiserBeta(double rejection)
static float SincKaiser(double r, double x)
{
- /* Limit rippling to -90dB. */
- return Kaiser(CalcKaiserBeta(90.0), x / r) * Sinc(x);
+ /* Limit rippling to -60dB. */
+ return Kaiser(CalcKaiserBeta(60.0), x / r) * Sinc(x);
}